"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const prompts_1 = __importDefault(require("prompts"));
const minimist_1 = __importDefault(require("minimist"));
const chalk_1 = __importDefault(require("chalk"));
const utils_1 = require("./utils");
const args = minimist_1.default(process.argv.slice(2));
const cwd = process.cwd();
const templates = ['default'];
const run = async () => {
    const { name, email } = utils_1.getNameAndEmail();
    const username = await utils_1.getGithubUsername(email);
    let targetDir = args._[0];
    if (!targetDir) {
        ;
        ({ projectName: targetDir } = await prompts_1.default({
            type: 'text',
            name: 'projectName',
            message: 'Project Name',
        }));
    }
    const packageName = targetDir
        .toLowerCase()
        .trim()
        .replace(/\s+/g, '-')
        .replace(/^[._]/, '')
        .replace(/[^a-z0-9-~]+/g, '-');
    const root = path_1.default.join(cwd, targetDir);
    if (!fs_1.default.existsSync(root)) {
        fs_1.default.mkdirSync(root, { recursive: true });
    }
    else {
        if (fs_1.default.readdirSync(root).length)
            throw new Error(`${root} is not a empty directory`);
    }
    if (!fs_1.default.existsSync(root)) {
        fs_1.default.mkdirSync(root, { recursive: true });
    }
    else {
        if (fs_1.default.readdirSync(root).length)
            throw new Error(`${root} is not a empty directory`);
    }
    let template = args.t || args.template;
    if (typeof template === 'string')
        template = templates.includes(template) ? template : null;
    if (!template)
        ({ template } = await prompts_1.default([
            {
                type: 'select',
                name: 'template',
                message: 'Choose a template',
                choices: templates.map((t) => ({
                    value: t,
                    title: chalk_1.default.cyan(t.replace('-starter', '')),
                })),
            },
        ]));
    const templateDir = path_1.default.join(__dirname, '..', `templates`, template);
    const pkgFile = path_1.default.join(templateDir, 'package.json');
    const pkgJson = require(pkgFile);
    pkgJson.name = packageName;
    pkgJson.author = `${name} <${email}>`;
    const repo = `https://github.com/${username}/${packageName}`;
    pkgJson.homepage = `${repo}#readme`;
    pkgJson.bugs = { url: `${repo}/issues` };
    pkgJson.repository = { type: 'git', url: `git+${repo}.git` };
    copy(templateDir, root);
    fs_1.default.writeFileSync(path_1.default.join(root, 'package.json'), JSON.stringify(pkgJson, null, 2));
    fs_1.default.writeFileSync(path_1.default.join(root, 'README.md'), utils_1.getReadme(packageName, username));
    console.log(chalk_1.default.cyanBright(`\nDone. Now run:\n`));
    if (root !== cwd)
        console.log(chalk_1.default.yellowBright(`> cd ${path_1.default.relative(cwd, root)}`));
    console.log(chalk_1.default.blueBright(`> yarn`));
    console.log();
};
function copy(src, dest) {
    if (fs_1.default.statSync(src).isDirectory()) {
        fs_1.default.mkdirSync(dest, { recursive: true });
        for (const file of fs_1.default.readdirSync(src)) {
            copy(path_1.default.join(src, file), path_1.default.join(dest, file));
        }
    }
    else {
        fs_1.default.copyFileSync(src, replace_(dest));
    }
}
function replace_(p) {
    return p.replace(/_gitignore$|_npmignore$|_eslintrc.json$|_prettierrc$/, (s) => s.replace('_', '.'));
}
module.exports = run;
//# sourceMappingURL=index.js.map