"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getReadme = exports.getGithubUsername = exports.getNameAndEmail = void 0;
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const ini_1 = __importDefault(require("ini"));
const path_1 = __importDefault(require("path"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const getNameAndEmail = () => {
    try {
        const configPath = path_1.default.join(os_1.default.homedir(), '.gitconfig');
        if (!fs_1.default.existsSync(configPath))
            throw new Error();
        const { user } = ini_1.default.parse(fs_1.default.readFileSync(configPath, 'utf-8'));
        if (!user)
            throw new Error();
        return {
            name: user.name || '<your-name>',
            email: user.email || '<your-email>',
        };
    }
    catch (e) {
        return {
            name: '<your-name>',
            email: '<your-email>',
        };
    }
};
exports.getNameAndEmail = getNameAndEmail;
const getGithubUsername = async (email) => {
    try {
        const searchUserUrl = `https://api.github.com/search/users?q=${email} in:email`;
        const { items } = await node_fetch_1.default(searchUserUrl).then((res) => res.json());
        if (items.length > 0)
            return items[0].login;
        const { version, platform, arch } = process;
        const data = await node_fetch_1.default(`https://api.github.com/search/commits?q=author-email:${email}&sort=author-date&per-page=1`, {
            method: 'GET',
            headers: {
                Accept: 'application/vnd.github.cloak-preview+json',
                'user-agent': `Node.js/${version.substr(1)} (${platform}; ${arch})`,
            },
        })
            .then((res) => res.json())
            .then((res) => res.items[0]);
        return data.author.login;
    }
    catch (err) {
        return '<your-username>';
    }
};
exports.getGithubUsername = getGithubUsername;
const getReadme = (pkgName, username) => {
    const npm = `https://npmjs.com/package/${pkgName}`;
    const repo = `https://github.com/${username}/${pkgName}`;
    const npmIcon = `https://img.shields.io/npm/v/${pkgName}`;
    const mitIcon = `https://img.shields.io/badge/license-MIT-blue.svg`;
    const workflowIcon = `https://img.shields.io/github/workflow/status/${username}/${pkgName}/CI`;
    const prIcon = `https://img.shields.io/badge/PRs-welcome-brightgreen.svg`;
    return `
# ${pkgName}

> Starter Generated by \`create-npm-starter\`
  
<a href="${npm}"><img alt="NPM" src="${npmIcon}" /></a>
<a href="${repo}"><img alt="MIT" src="${mitIcon}" /></a>
<a href="#"><img alt="CI" src="${workflowIcon}"></a>
<a href="${repo}"><img src="${prIcon}" alt="PRs welcome!" /></a>
  `.trim();
};
exports.getReadme = getReadme;
//# sourceMappingURL=utils.js.map