import { COLORS, ColorThemeContext, Spinner } from '@zebrainy/react-components';
import * as React from 'react';
import { Auth } from './components/Auth';
import { AboutScreen } from './components/AboutScreen';
import { Start } from './components/Start';
import { Subscription } from './components/Subscription';
import { StateMachine } from './state/context';
import { InstructionScreen } from './components/InstructionScreen';
import { Cancelation } from './components/Cancelation';
import { MenuSidebar } from './components/MenuSidebar';
import { IntercomContainer, IntercomProvider } from '@zebrainy/react-common';
import { getIntercomUserId } from '@zebrainy/front-functions';

export const StateContext = React.createContext<StateMachine>(
  {} as StateMachine
)

export const App: React.FC<StateMachine> = ({ main }) =>
{

  const renderComponent = () =>
  {
    switch (main.model.state)
    {

      case 'auth':
        return <Auth />

      case 'start':
        return <Start />

      case 'subscription':
        return <Subscription />

      case 'instruction':
        return <InstructionScreen />

      case 'about':
        return <AboutScreen />

      case 'cancelation':
        return <Cancelation />

      case 'not_auth':
      default:
        return <Spinner />
    }
  }

  return (
    <IntercomProvider>
      <StateContext.Provider value={{ main }}>
        <ColorThemeContext.Provider value={COLORS['green']}>
          {renderComponent()}
          {main.model.sidebarOpen && <MenuSidebar />}
          <IntercomContainer
            web_module={'cloud-payments_web-cabinet'}
            device_os={'Ios'}
            language={'Rus'}
            system_memory_size={0}
            free_memory_space={0}
            client_version={''}
            user_id={getIntercomUserId(main.model.userId, '0')}
          />
        </ColorThemeContext.Provider>
      </StateContext.Provider>
    </IntercomProvider>
  )
}
