import axios, { AxiosRequestConfig, AxiosResponse, Method } from 'axios'
import { SubscriptionCurrentType } from './types'

let log_req = (request: AxiosRequestConfig) =>
{
	console.log(`[Web_Request]: [Url]: ${request.url}, [Method]: ${request.method?.toUpperCase()}, [Body]: ${JSON.stringify(!!request.data ? request.data : '')}`)
}

let log_res = (response: AxiosResponse) =>
{
	console.log(`[Web_Response]: [Url]: ${response.config.url}, [Method]: ${response.config.method?.toUpperCase()}, [Status_Code]: ${response.status} ${response.statusText}, [Body]: ${JSON.stringify(response.data)}`)
}

const getServerUrl = () => {
    if (window.location.host.startsWith('localhost'))
        return 'http://localhost:3000'
    return window.location.href.replace(/\/$/, '').replace(/\/front$/, '')
}

export class СloudPaymentsWebAPI
{
	private static authToken: string = ''
	private static host: string = getServerUrl()


	static setToken(token: string)
	{
		this.authToken = token
	}

	static auth(authData: { email: string, passcode: string }): Promise<{ access_token: string }>
	{
		return this.apiRequest(`/auth/getToken`, 'POST', authData)
	}

	static getPasscode(): Promise<{ passcode: string }>
	{
		return this.apiRequest(`/user/passcode`, 'GET')
	}

	static getCurrentSubscription(): Promise<SubscriptionCurrentType>
	{
		return this.apiRequest(`/subscriptions/current`, 'POST')
	}

	static cancelSubscription(subscriptionId: number)
	{
		return this.apiRequest(`/subscriptions/cancel`, 'POST', { subscriptionId })
	}

	private static async apiRequest<T extends any>(path: string, method: Method, data?: any)
	{
		let response = await axios.request({
			method,
			data,
			url: `${this.host}${path}`,
			headers: {
				...(this.authToken ? { 'Authorization': `Bearer ${this.authToken}` } : {})
			}
		})

		axios.interceptors.request.use(request =>
		{
			log_req(request)
			return request
		})

		axios.interceptors.response.use(response =>
		{
			log_res(response)
			return response
		})

		return response.data as T
	}
}
