import { validateEmail } from '@zebrainy/front-functions'
import { useIntercom } from '@zebrainy/react-common'
import { AuthScreen, ButtonLabelStatusType } from '@zebrainy/react-components'
import React from 'react'
import { StateContext } from '../App'
import { useInput } from '../hooks'

export const Auth: React.FC = () =>
{
	const ctx = React.useContext(StateContext)
	const [error, setError] = React.useState('')
	const [buttonStatus, setButtonStatus] = React.useState<ButtonLabelStatusType>('prepare')

	const email = useInput()
	const passcode = useInput()

	const intercom = useIntercom()

	const auth = async () =>
	{
		if (!email.value || !passcode.value || !validateEmail(email.value))
		{
			setButtonStatus('prepare')
			setError('Неверный email или пароль')
		} else
		{
			setButtonStatus('load')
			ctx.main.messages.authorize({ email: email.value, passcode: passcode.value })
		}
	}

	return (
		<AuthScreen.MainContext.Provider value={{
			buttonLabelStatus: buttonStatus,
			inputEmailValue: email.value,
			inputPasscodeValue: passcode.value,
			onEmailChange: email.onChange,
			onPasscodeChange: passcode.onChange,
			onButtonClick: buttonStatus == 'prepare' ? () => auth() : () => { },
			onHelpClick: () => intercom.open(),
			onRecoverClick: () => { },
			onInputClick: () => setError('')
		}}>
			<AuthScreen.LocalizationContext.Provider value={{
				title: 'Войдите в Ваш аккаунт',
				inputEmailPlaceholder: 'Ваш email',
				inputPasscodePlaceholder: 'Пароль',
				buttonLabel: 'Войти',
				recoverText: 'Не помню пароль',
				helpText: 'Мне нужна помощь',
				inputErrorMessage: error
			}}>
				<AuthScreen.AnalyticsContext.Provider value={{}}>
					<AuthScreen.Screen />
				</AuthScreen.AnalyticsContext.Provider>
			</AuthScreen.LocalizationContext.Provider>
		</AuthScreen.MainContext.Provider >
	)
}
