import { CopyButton, Instruction } from '@zebrainy/react-components'
import copy from 'copy-to-clipboard'
import React from 'react'
import { StateContext } from '../App'
import { PopUpCopy } from './PopUpCopy'

export const InstructionScreen: React.FC = () =>
{
	const ctx = React.useContext(StateContext)
	const [copied, setCopied] = React.useState(false)

	const copyPasscode = () =>
	{
		copy(ctx.main.model.passcode)
		setCopied(true)
	}

	const openStorePage = (url: string) =>
	{
		window.open(url, '_blank')
	}

	return (
		<>
			<Instruction
				title={'Как начать играть?'}
				subStatusText={!!ctx.main.model.subscriptionCurrent.subscriptionId ? 'Ваша подписка активна' : ''}
				onBurgerClick={() => ctx.main.messages.set_sidebar_open()}
				onGoogleClick={() => openStorePage('https://apps.apple.com/ru/app/%D1%81%D0%BA%D0%B0%D0%B7%D0%B1%D1%83%D0%BA%D0%B0-%D1%80%D0%B0%D0%B7%D0%B2%D0%B8%D0%B2%D0%B0%D1%8E%D1%89%D0%B8%D0%B5-%D0%B8%D0%B3%D1%80%D1%8B-3-6/id1395112217')}
				onAppleClick={() => openStorePage('https://play.google.com/store/apps/details?id=com.zebrainy.skazbuka&hl=ru&gl=US')}
				appleStoreButtonText={'Скачать в App Store'}
				googleStoreButtonText={'Скачать в Google Play'}
				orderedListItems={[
					'Установите Сказбуку из App Store',
					'Запустите приложение, пройдите все экраны до выбора подписки.',
					<>Нажмите <b>Восстановить покупки</b></>,
					<>Выберите <b>Наш сайт</b></>,
					<div style={{ 'display': 'flex', justifyContent: 'flex-start', 'flexWrap': 'wrap', alignItems: 'center' }}>
						Введите email: <b>{ctx.main.model.email}</b> и ваш пароль: <b>{ctx.main.model.passcode}</b>
						<CopyButton isCopied={copied} text={'Копировать'} onClick={copyPasscode} />
					</div>
				]}
			/>
			{copied && <PopUpCopy onClose={() => setCopied(false)} />}
		</>
	)
}
