import { env } from './../env';
import { JWTInnerPayload, JWTPayload } from './../types';
import jwtDecode from 'jwt-decode'
import { extractAccessToken } from './../utils'
import { NextFunction, Request, Response as ExResponse } from 'express'
import jwt from "jsonwebtoken"
import expressAsyncHandler from 'express-async-handler'



export const AuthMiddlewares = {
    verifyUserAccessToken: expressAsyncHandler(async (req: Request, res: ExResponse, next: NextFunction) => {
        const token = extractAccessToken(req)
        if (!token) {
            res.status(400).send({ error: 'Token is required' })
            return
        }
        try {
            // await api.verifyToken(token)
        } catch {
            res.status(401).send({ error: 'Unauthorized' })
            return
        }
        const decoded = jwtDecode<JWTPayload>(token)
        req.__locals.userData = decoded
        next()
    }),
    verifyInternalToken: expressAsyncHandler(async (req: Request, res: ExResponse, next: NextFunction) => {
        const token = extractAccessToken(req)
        if (!token) {
            res.status(400).send({ error: 'Token is required' })
            return
        }
        try {
            let decoded = jwt.verify(token, env.JWT_SECRET) as JWTInnerPayload;
            req.__locals.tokenData = decoded
        } catch {
            res.status(401).send({ error: 'Unauthorized' })
            return
        }
        next()
    }),
}

