import * as promise from 'bluebird'; // best promise library today
// import * as dbConfig from '../../db-config.json'; // db connection details
import { env } from "../env"
import pgPromise from 'pg-promise'; // pg-promise core library
import {IInitOptions, IDatabase, IMain} from 'pg-promise';
import {IExtensions, TransactionsRepository} from './repos';
import { UsersRepository } from './repos/users';
import { ProductsRepository } from './repos/products';
import { TariffPlansRepository } from './repos/tariffPlan';
import { SubscriptionsRepository } from './repos/subscriptions';

type ExtendedProtocol = IDatabase<IExtensions> & IExtensions;

// pg-promise initialization options:
const initOptions: IInitOptions<IExtensions> = {
    // Using a custom promise library, instead of the default ES6 Promise:
    promiseLib: promise,

    // Extending the database protocol with our custom repositories;
    // API: http://vitaly-t.github.io/pg-promise/global.html#event:extend
    extend(obj: ExtendedProtocol, dc: any) {
        // Database Context (dc) is mainly needed for extending multiple databases with different access API.

        // Do not use 'require()' here, because this event occurs for every task and transaction being executed,
        // which should be as fast as possible.
        obj.transactions = new TransactionsRepository(obj, pgp)
        obj.users= new UsersRepository(obj, pgp)
        obj.products = new ProductsRepository(obj, pgp)
        obj.tariffPlans = new TariffPlansRepository(obj, pgp)
        obj.subscriptions = new SubscriptionsRepository(obj, pgp)
    }
};

// Initializing the library:
const pgp: IMain = pgPromise(initOptions);

// Creating the database instance with extensions:
const db: ExtendedProtocol = pgp(env.DATABASE_URL);

// Alternatively, you can get access to pgp via db.$config.pgp
// See: https://vitaly-t.github.io/pg-promise/Database.html#$config
export {db, pgp};
