/*
  tools for generating database models automatically
  schemats: https://github.com/sweetiq/schemats
*/

export interface DataRecord
{
  "id": number,
  "created_date": string,
  "created_by": number,
  "modified_date": string,
  "modified_by": number,
}

export interface User extends DataRecord
{
  "state": number,
  "password_hash": string,
  "uuid": string | null,
  "name": string | null,
  "email": string | null,
  "phone": string | null,
  "timezone_offset": number,
  "is_subscribed": boolean,
  "debug_mask": number,
  "os_type": number,
  "migration_state": number,
  "language_id": number,
  "accept_terms_of_use": boolean,
  "country": string | null,
  "firebase_uid": string | null,
  "flags": number
}

export interface Product extends DataRecord
{
  "state": number,
  "name": string,
  "description": string,
  "length": number,
  "os_type": number,
  "type": number,
  "product_group_id": number | null,
  "duration": string
}

export interface DbTransaction extends Transaction, DataRecord {}
export interface Transaction
{
  "utid": string,
  "user_id": number,
  "user_subscription_id": number,
  "start_date": Date,
  "end_date": Date,
  "receipt": object,
  "state": number,
  "environment": string | null
}

export interface DbSubscription extends Subscription, DataRecord {}
export interface Subscription
{
  "state": number,
  "start_date": Date,
  "end_date": Date,
  "user_id": number,
  "product_id": number,
  "promocode_id": number | null,
  "is_trial_period": boolean,
  "is_auto_renew_status": boolean,
  "currency_id": number,
  "intro_price": number,
  "main_price": number,
  "is_grace_period": boolean,
  "grace_period_date_end": Date | null,
  "usid": string | null,
  "is_intro_period": boolean,
  "is_family_shared": boolean,
  "rebill_id": number | null
}


export interface DbTariffPlan extends TariffPlan, DataRecord {}
export interface TariffPlan
{
  "state": number,
  "product_type_id": number,
  "tariff_plan_id": number,
  "user_id": number,
  "user_subscription_id": number,
  "max_devices": number | null,
  "share_subscription_id": number | null
}