import { IDatabase, IMain } from 'pg-promise';
import { IResult } from 'pg-promise/typescript/pg-subset';
import { DbSubscription, Subscription } from '../models';
import { subscriptions as sql } from '../sql';

/*
 This repository mixes hard-coded and dynamic SQL, just to show how to use both.
*/

export class SubscriptionsRepository
{

    /**
     * @param db
     * Automated database connection context/interface.
     *
     * If you ever need to access other repositories from this one,
     * you will have to replace type 'IDatabase<any>' with 'any'.
     *
     * @param pgp
     * Library's root, if ever needed, like to access 'helpers'
     * or other namespaces available from the root.
     */
    constructor(private db: IDatabase<any>, private pgp: IMain)
    {
        /*
          If your repository needs to use helpers like ColumnSet,
          you should create it conditionally, inside the constructor,
          i.e. only once, as a singleton.
        */
    }

    async findByTransactionId(transactionId: number): Promise<DbSubscription | null> {
        return this.db.oneOrNone('SELECT * FROM core.user_subscription WHERE usid = $1', transactionId);
    }

    async findByUserId(userId: number): Promise<DbSubscription | null> {
        return this.db.oneOrNone('SELECT * FROM core.user_subscription WHERE user_id = $1', userId);
    }

    async add(values: Subscription): Promise<DbSubscription>
    {
        var current_date = new Date()
        return this.db.one(sql.add,
            {
                created_date: current_date,
                created_by: 1,
                modified_date: current_date,
                modified_by: 1,
                ...values
            });
    }
}
