import axios from "axios"
import express, { Request } from "express"
import { env } from "./env"



export const extractAccessToken = (req: Request) => {
    return req.headers.authorization?.split(' ')?.[1]
}

export const pick = <T, K extends keyof T>(keys: K[], obj: T) => {
    return keys.reduce((acc, key) => {

        //@ts-ignore
        acc[key] = obj[key]
        return acc
    }, {} as Pick<T, Extract<keyof T, K>>)
}


const stringifyErr = (e: unknown) => {
    if (axios.isAxiosError(e))
        return (
            `${e.name} ${e.code || e.response?.status || ''} ${e.response?.statusText || ''
            }:` +
            `${e.config.method} ${e.config.baseURL || ''}${e.config.url || ''
            }\n${JSON.stringify(e.response?.data)}`
        )

    if (e instanceof Error) return `${e.name}: ${e.message}\n${e.stack}`

    return JSON.stringify(e)
}

export const exressHandleError: express.ErrorRequestHandler = (
    err,
    req,
    res,
    next
) => {
    const error = stringifyErr(err)
    console.error(error)
    res.status(400).json({ error: error })
}